| grmtree_data | R Documentation |
A dataset containing sample responses to the MOS-SS emotional domain items and demographic variables. This data is provided for testing and demonstration purposes within the grmtree package. The items are numbered 1-5, representing None of the time, A little of the time, Some of the time, Most of the time, All of the time, respectively.
grmtree_data
A tibble with 3,500 rows and 17 variables:
Someone you can count on to listen to you when you need to talk (1-5 Likert scale)
Someone to give you information to help you understand a situation (1-5 Likert scale)
Someone to give good advice about a crisis (1-5 Likert scale)
Someone to confide in or talk to about yourself or your problems (1-5 Likert scale)
Someone whose advice you really want (1-5 Likert scale)
Someone to share private worries or fears (1-5 Likert scale)
Someone to turn to for suggestions about how to deal with a personal problem (1-5 Likert scale)
Someone who understands your problems (1-5 Likert scale)
Gender (Male, Female)
Age in years (numeric)
Residence location (rural, urban)
Depression status (No, Yes)
Body Mass Index (numeric)
Education level (Primary/High school, College/University)
Employment status (Employed, Unemployed)
Smoking status (No, Yes)
Number of chronic conditions (0, 1, 2+)
Simulated data generated for package testing and demonstration
library(dplyr)
# Load and take a glimpse at the data
data(grmtree_data, package = "grmtree")
glimpse(grmtree_data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.