threshpar_grmtree: Extract Threshold Parameters from GRM Tree

View source: R/grmtree-threshpar.R

threshpar_grmtreeR Documentation

Extract Threshold Parameters from GRM Tree

Description

Extracts threshold parameters for each item from all terminal nodes of a graded response model tree. The thresholds represent the points on the latent trait continuum where the probability of scoring in adjacent response categories is equal.

Usage

threshpar_grmtree(object, node = NULL, ...)

Arguments

object

A grmtree object.

node

Optional vector of node IDs to extract from. If NULL (default), extracts from all terminal nodes.

...

Additional arguments (currently unused).

Value

A data.frame with threshold parameters for each item in each node, with columns:

Node

Node ID

Item

Item name

d1, d2, ...

Threshold parameters for each category

See Also

grmtree fits a Graded Response Model Tree, grmforest for GRM Forests, fscores_grmtree for computing factor scores, discrpar_grmtree for extracting discrimination parameters, itempar_grmtree for extracting item parameters

Examples


library(grmtree)
library(hlt)

  data("asti", package = "hlt")
  asti$resp <- data.matrix(asti[, 1:4])

  # Fit GRM tree with gender and group as partitioning variables
  tree <- grmtree(resp ~ gender + group,
          data = asti,
          control = grmtree.control(minbucket = 30))

  # Get all thresholds
  thresholds <- threshpar_grmtree(tree)
  print(thresholds)



grmtree documentation built on Sept. 2, 2026, 1:07 a.m.