View source: R/grmtree-applytomodels.R
| apply_to_models | R Documentation |
Applies a function to the GRM models in specified nodes of a tree. This is an internal helper function and not meant to be called directly.
apply_to_models(object, node = NULL, FUN = NULL, drop = FALSE, ...)
object |
A |
node |
Vector of node IDs (default: all nodes). |
FUN |
Function to apply to each model. |
drop |
Logical indicating whether to drop list structure if length 1. |
... |
Additional arguments passed to FUN. |
List of results (or single result if drop=TRUE and length(node)=1).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.