View source: R/grmtree-control.R
| grmtree.control | R Documentation |
Creates a control object for grmtree containing various parameters that
control the tree growing process.
grmtree.control(
minbucket = 20,
p_adjust = "none",
alpha = 0.05,
initial_alpha = NULL,
...
)
minbucket |
Minimum number of observations in a terminal node (default: 20). |
p_adjust |
Method for p-value adjustment. One of: "none", "bonferroni", "holm", "BH", "BY", "hochberg", or "hommel" (default: "none"). |
alpha |
Significance level for splitting (default: 0.05). |
initial_alpha |
For post-hoc adjustment methods (holm, BH, BY, hochberg,
hommel), the significance threshold for initial tree construction before
pruning. Must satisfy |
... |
Additional arguments passed to |
A list of control parameters with class grmtree_control.
grmtree fits a Graded Response Model Tree
# Use Bonferroni correction with alpha = 0.01
ctrl <- grmtree.control(p_adjust = "bonferroni", alpha = 0.01)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.